[nautilus-actions] NAIContext interface is renamed to FMAIContext



commit 564e91999257d92f6d1d69e22f8fde4b7249dbbe
Author: Pierre Wieser <pwieser trychlos org>
Date:   Mon Sep 7 22:02:15 2015 +0200

    NAIContext interface is renamed to FMAIContext

 src/api/Makefile.am                                |    2 +-
 src/api/{na-icontext.h => fma-icontext.h}          |   50 ++--
 src/api/na-ifactory-object-data.h                  |    2 +-
 src/api/na-object-api.h                            |   14 +-
 src/core/Makefile.am                               |    4 +-
 ...a-icontext-factory.c => fma-icontext-factory.c} |    0
 src/core/{na-icontext.c => fma-icontext.c}         |  230 ++++++++++----------
 src/core/na-object-action-factory.c                |    2 +-
 src/core/na-object-action.c                        |   12 +-
 src/core/na-object-menu-factory.c                  |    2 +-
 src/core/na-object-menu.c                          |   12 +-
 src/core/na-object-profile-factory.c               |    2 +-
 src/core/na-object-profile.c                       |   12 +-
 src/core/na-object.c                               |   12 +-
 src/nact/nact-iaction-tab.c                        |    4 +-
 src/nact/nact-iaction-tab.h                        |    2 +-
 src/nact/nact-ibasenames-tab.c                     |    4 +-
 src/nact/nact-icapabilities-tab.c                  |   12 +-
 src/nact/nact-icommand-tab.c                       |    4 +-
 src/nact/nact-ienvironment-tab.c                   |   20 +-
 src/nact/nact-ifolders-tab.c                       |    2 +-
 src/nact/nact-imimetypes-tab.c                     |    2 +-
 src/nact/nact-iproperties-tab.c                    |    4 +-
 src/nact/nact-ischemes-tab.c                       |    4 +-
 src/nact/nact-main-tab.h                           |    2 +-
 src/nact/nact-main-window.c                        |   20 +-
 src/nact/nact-match-list.c                         |   18 +-
 src/nact/nact-schemes-list.c                       |    4 +-
 src/nact/nact-schemes-list.h                       |    4 +-
 src/nact/nact-tree-model.c                         |    4 +-
 src/plugin-menu/nautilus-actions.c                 |   18 +-
 src/utils/nautilus-actions-run.c                   |    4 +-
 32 files changed, 244 insertions(+), 244 deletions(-)
---
diff --git a/src/api/Makefile.am b/src/api/Makefile.am
index c01c9fb..253a954 100644
--- a/src/api/Makefile.am
+++ b/src/api/Makefile.am
@@ -44,7 +44,7 @@ api_include_HEADERS = \
        fma-data-types.h                                                                                \
        fma-gconf-monitor.h                                                                     \
        fma-gconf-utils.h                                                                       \
-       na-icontext.h                                                                           \
+       fma-icontext.h                                                                          \
        na-iduplicable.h                                                                        \
        na-ifactory-object.h                                                            \
        na-ifactory-object-data.h                                                       \
diff --git a/src/api/na-ifactory-object-data.h b/src/api/na-ifactory-object-data.h
index 2605fd6..dad511f 100644
--- a/src/api/na-ifactory-object-data.h
+++ b/src/api/na-ifactory-object-data.h
@@ -130,7 +130,7 @@ G_BEGIN_DECLS
  *
  * The datas which determine the display conditions of a menu or an action.
  *
- * @see_also: #NAIContext interface.
+ * @see_also: #FMAIContext interface.
  */
 #define NA_FACTORY_OBJECT_CONDITIONS_GROUP  "na-factory-group-conditions"
 #define NAFO_DATA_BASENAMES                 "na-factory-data-basenames"
diff --git a/src/api/na-object-api.h b/src/api/na-object-api.h
index 72c3391..8a1193d 100644
--- a/src/api/na-object-api.h
+++ b/src/api/na-object-api.h
@@ -44,7 +44,7 @@
 #include "na-ifactory-object.h"
 #include "na-ifactory-object-data.h"
 #include "na-iduplicable.h"
-#include "na-icontext.h"
+#include "fma-icontext.h"
 #include "na-object-action.h"
 #include "na-object-profile.h"
 #include "na-object-menu.h"
@@ -174,9 +174,9 @@ G_BEGIN_DECLS
 #define na_object_set_startup_class( obj, class )       na_ifactory_object_set_from_void( 
NA_IFACTORY_OBJECT( obj ), NAFO_DATA_STARTUP_WMCLASS, ( const void * )( class ))
 #define na_object_set_execute_as( obj, user )           na_ifactory_object_set_from_void( 
NA_IFACTORY_OBJECT( obj ), NAFO_DATA_EXECUTE_AS, ( const void * )( user ))
 
-/* NAIContext
+/* FMAIContext
  */
-#define na_object_check_mimetypes( obj )                na_icontext_check_mimetypes( NA_ICONTEXT( obj ))
+#define na_object_check_mimetypes( obj )                fma_icontext_check_mimetypes( FMA_ICONTEXT( obj ))
 
 #define na_object_get_basenames( obj )                  (( GSList * ) na_ifactory_object_get_as_void( 
NA_IFACTORY_OBJECT( obj ), NAFO_DATA_BASENAMES ))
 #define na_object_get_matchcase( obj )                  (( gboolean ) GPOINTER_TO_UINT( 
na_ifactory_object_get_as_void( NA_IFACTORY_OBJECT( obj ), NAFO_DATA_MATCHCASE )))
@@ -198,13 +198,13 @@ G_BEGIN_DECLS
 #define na_object_set_mimetypes( obj, types )           na_ifactory_object_set_from_void( 
NA_IFACTORY_OBJECT( obj ), NAFO_DATA_MIMETYPES, ( const void * )( types ))
 #define na_object_set_all_mimetypes( obj, all )         na_ifactory_object_set_from_void( 
NA_IFACTORY_OBJECT( obj ), NAFO_DATA_MIMETYPES_IS_ALL, ( const void * ) GUINT_TO_POINTER( all ))
 #define na_object_set_folders( obj, folders )           na_ifactory_object_set_from_void( 
NA_IFACTORY_OBJECT( obj ), NAFO_DATA_FOLDERS, ( const void * )( folders ))
-#define na_object_replace_folder( obj, old, new )       na_icontext_replace_folder( NA_ICONTEXT( obj ), ( 
const gchar * )( old ), ( const gchar * )( new ))
-#define na_object_set_scheme( obj, scheme, add )        na_icontext_set_scheme( NA_ICONTEXT( obj ), ( const 
gchar * )( scheme ), ( add ))
+#define na_object_replace_folder( obj, old, new )       fma_icontext_replace_folder( FMA_ICONTEXT( obj ), ( 
const gchar * )( old ), ( const gchar * )( new ))
+#define na_object_set_scheme( obj, scheme, add )        fma_icontext_set_scheme( FMA_ICONTEXT( obj ), ( 
const gchar * )( scheme ), ( add ))
 #define na_object_set_schemes( obj, schemes )           na_ifactory_object_set_from_void( 
NA_IFACTORY_OBJECT( obj ), NAFO_DATA_SCHEMES, ( const void * )( schemes ))
 #define na_object_set_only_show_in( obj, list )         na_ifactory_object_set_from_void( 
NA_IFACTORY_OBJECT( obj ), NAFO_DATA_ONLY_SHOW, ( const void * )( list ))
-#define na_object_set_only_desktop( obj, desktop, add ) na_icontext_set_only_desktop( NA_ICONTEXT( obj ), ( 
const gchar * )( desktop ), ( add ))
+#define na_object_set_only_desktop( obj, desktop, add ) fma_icontext_set_only_desktop( FMA_ICONTEXT( obj ), 
( const gchar * )( desktop ), ( add ))
 #define na_object_set_not_show_in( obj, list )          na_ifactory_object_set_from_void( 
NA_IFACTORY_OBJECT( obj ), NAFO_DATA_NOT_SHOW, ( const void * )( list ))
-#define na_object_set_not_desktop( obj, desktop, add )  na_icontext_set_not_desktop( NA_ICONTEXT( obj ), ( 
const gchar * )( desktop ), ( add ))
+#define na_object_set_not_desktop( obj, desktop, add )  fma_icontext_set_not_desktop( FMA_ICONTEXT( obj ), ( 
const gchar * )( desktop ), ( add ))
 #define na_object_set_try_exec( obj, exec )             na_ifactory_object_set_from_void( 
NA_IFACTORY_OBJECT( obj ), NAFO_DATA_TRY_EXEC, ( const void * )( exec ))
 #define na_object_set_show_if_registered( obj, name )   na_ifactory_object_set_from_void( 
NA_IFACTORY_OBJECT( obj ), NAFO_DATA_SHOW_IF_REGISTERED, ( const void * )( name ))
 #define na_object_set_show_if_true( obj, exec )         na_ifactory_object_set_from_void( 
NA_IFACTORY_OBJECT( obj ), NAFO_DATA_SHOW_IF_TRUE, ( const void * )( exec ))
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index b0f35cf..82a3249 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -76,8 +76,8 @@ libna_core_la_SOURCES = \
        na-gnome-vfs-uri.h                                                                      \
        na-gtk-utils.c                                                                          \
        na-gtk-utils.h                                                                          \
-       na-icontext.c                                                                           \
-       na-icontext-factory.c                                                           \
+       fma-icontext.c                                                                          \
+       fma-icontext-factory.c                                                          \
        na-iduplicable.c                                                                        \
        na-iexporter.c                                                                          \
        na-ifactory-object.c                                                            \
diff --git a/src/core/na-icontext-factory.c b/src/core/fma-icontext-factory.c
similarity index 100%
rename from src/core/na-icontext-factory.c
rename to src/core/fma-icontext-factory.c
diff --git a/src/core/na-icontext.c b/src/core/fma-icontext.c
similarity index 79%
rename from src/core/na-icontext.c
rename to src/core/fma-icontext.c
index ff885de..30a5e6c 100644
--- a/src/core/na-icontext.c
+++ b/src/core/fma-icontext.c
@@ -57,49 +57,49 @@
 
 /* private interface data
  */
-struct _NAIContextInterfacePrivate {
+struct _FMAIContextInterfacePrivate {
        void *empty;                                            /* so that gcc -pedantic is happy */
 };
 
 static guint st_initializations = 0;   /* interface initialization count */
 
 static GType        register_type( void );
-static void         interface_base_init( NAIContextInterface *klass );
-static void         interface_base_finalize( NAIContextInterface *klass );
-
-static gboolean     v_is_candidate( NAIContext *object, guint target, GList *selection );
-
-static gboolean     is_candidate_for_target( const NAIContext *object, guint target, GList *files );
-static gboolean     is_candidate_for_show_in( const NAIContext *object, guint target, GList *files );
-static gboolean     is_candidate_for_try_exec( const NAIContext *object, guint target, GList *files );
-static gboolean     is_candidate_for_show_if_registered( const NAIContext *object, guint target, GList 
*files );
-static gboolean     is_candidate_for_show_if_true( const NAIContext *object, guint target, GList *files );
-static gboolean     is_candidate_for_show_if_running( const NAIContext *object, guint target, GList *files );
-static gboolean     is_candidate_for_mimetypes( const NAIContext *object, guint target, GList *files );
+static void         interface_base_init( FMAIContextInterface *klass );
+static void         interface_base_finalize( FMAIContextInterface *klass );
+
+static gboolean     v_is_candidate( FMAIContext *object, guint target, GList *selection );
+
+static gboolean     is_candidate_for_target( const FMAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_show_in( const FMAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_try_exec( const FMAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_show_if_registered( const FMAIContext *object, guint target, GList 
*files );
+static gboolean     is_candidate_for_show_if_true( const FMAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_show_if_running( const FMAIContext *object, guint target, GList *files 
);
+static gboolean     is_candidate_for_mimetypes( const FMAIContext *object, guint target, GList *files );
 static gboolean     is_all_mimetype( const gchar *mimetype );
 static gboolean     is_file_mimetype( const gchar *mimetype );
 static gboolean     is_mimetype_of( const gchar *file_type, const gchar *ftype, gboolean is_regular );
-static gboolean     is_candidate_for_basenames( const NAIContext *object, guint target, GList *files );
-static gboolean     is_candidate_for_selection_count( const NAIContext *object, guint target, GList *files );
-static gboolean     is_candidate_for_schemes( const NAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_basenames( const FMAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_selection_count( const FMAIContext *object, guint target, GList *files 
);
+static gboolean     is_candidate_for_schemes( const FMAIContext *object, guint target, GList *files );
 static gboolean     is_compatible_scheme( const gchar *pattern, const gchar *scheme );
-static gboolean     is_candidate_for_folders( const NAIContext *object, guint target, GList *files );
-static gboolean     is_candidate_for_capabilities( const NAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_folders( const FMAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_capabilities( const FMAIContext *object, guint target, GList *files );
 
-static gboolean     is_valid_basenames( const NAIContext *object );
-static gboolean     is_valid_mimetypes( const NAIContext *object );
-static gboolean     is_valid_schemes( const NAIContext *object );
-static gboolean     is_valid_folders( const NAIContext *object );
+static gboolean     is_valid_basenames( const FMAIContext *object );
+static gboolean     is_valid_mimetypes( const FMAIContext *object );
+static gboolean     is_valid_schemes( const FMAIContext *object );
+static gboolean     is_valid_folders( const FMAIContext *object );
 
 static gboolean     is_positive_assertion( const gchar *assertion );
 
 /**
- * na_icontext_get_type:
+ * fma_icontext_get_type:
  *
  * Returns: the #GType type of this interface.
  */
 GType
-na_icontext_get_type( void )
+fma_icontext_get_type( void )
 {
        static GType type = 0;
 
@@ -111,18 +111,18 @@ na_icontext_get_type( void )
 }
 
 /*
- * na_icontext_register_type:
+ * fma_icontext_register_type:
  *
  * Registers this interface.
  */
 static GType
 register_type( void )
 {
-       static const gchar *thisfn = "na_icontext_register_type";
+       static const gchar *thisfn = "fma_icontext_register_type";
        GType type;
 
        static const GTypeInfo info = {
-               sizeof( NAIContextInterface ),
+               sizeof( FMAIContextInterface ),
                ( GBaseInitFunc ) interface_base_init,
                ( GBaseFinalizeFunc ) interface_base_finalize,
                NULL,
@@ -135,7 +135,7 @@ register_type( void )
 
        g_debug( "%s", thisfn );
 
-       type = g_type_register_static( G_TYPE_INTERFACE, "NAIContext", &info, 0 );
+       type = g_type_register_static( G_TYPE_INTERFACE, "FMAIContext", &info, 0 );
 
        g_type_interface_add_prerequisite( type, G_TYPE_OBJECT );
 
@@ -143,24 +143,24 @@ register_type( void )
 }
 
 static void
-interface_base_init( NAIContextInterface *klass )
+interface_base_init( FMAIContextInterface *klass )
 {
-       static const gchar *thisfn = "na_icontext_interface_base_init";
+       static const gchar *thisfn = "fma_icontext_interface_base_init";
 
        if( !st_initializations ){
 
                g_debug( "%s: klass%p (%s)", thisfn, ( void * ) klass, G_OBJECT_CLASS_NAME( klass ));
 
-               klass->private = g_new0( NAIContextInterfacePrivate, 1 );
+               klass->private = g_new0( FMAIContextInterfacePrivate, 1 );
        }
 
        st_initializations += 1;
 }
 
 static void
-interface_base_finalize( NAIContextInterface *klass )
+interface_base_finalize( FMAIContextInterface *klass )
 {
-       static const gchar *thisfn = "na_icontext_interface_base_finalize";
+       static const gchar *thisfn = "fma_icontext_interface_base_finalize";
 
        st_initializations -= 1;
 
@@ -173,22 +173,22 @@ interface_base_finalize( NAIContextInterface *klass )
 }
 
 /**
- * na_icontext_are_equal:
- * @a: the (original) #NAIContext context.
- * @b: the (duplicated) #NAIContext context to be checked.
+ * fma_icontext_are_equal:
+ * @a: the (original) #FMAIContext context.
+ * @b: the (duplicated) #FMAIContext context to be checked.
  *
  * Returns: %TRUE if this @a and @b are equal, %FALSE else.
  *
  * Since: 3.1
  */
 gboolean
-na_icontext_are_equal( const NAIContext *a, const NAIContext *b )
+fma_icontext_are_equal( const FMAIContext *a, const FMAIContext *b )
 {
-       static const gchar *thisfn = "na_icontext_are_equal";
+       static const gchar *thisfn = "fma_icontext_are_equal";
        gboolean are_equal;
 
-       g_return_val_if_fail( NA_IS_ICONTEXT( a ), FALSE );
-       g_return_val_if_fail( NA_IS_ICONTEXT( b ), FALSE );
+       g_return_val_if_fail( FMA_IS_ICONTEXT( a ), FALSE );
+       g_return_val_if_fail( FMA_IS_ICONTEXT( b ), FALSE );
 
        g_debug( "%s: a=%p, b=%p", thisfn, ( void * ) a, ( void * ) b );
 
@@ -198,8 +198,8 @@ na_icontext_are_equal( const NAIContext *a, const NAIContext *b )
 }
 
 /**
- * na_icontext_is_candidate:
- * @context: a #NAIContext to be checked.
+ * fma_icontext_is_candidate:
+ * @context: a #FMAIContext to be checked.
  * @target: the current target.
  * @selection: the currently selected items, as a #GList of NASelectedInfo items.
  *
@@ -218,17 +218,17 @@ na_icontext_are_equal( const NAIContext *a, const NAIContext *b )
  * Since: 2.30
  */
 gboolean
-na_icontext_is_candidate( const NAIContext *context, guint target, GList *selection )
+fma_icontext_is_candidate( const FMAIContext *context, guint target, GList *selection )
 {
-       static const gchar *thisfn = "na_icontext_is_candidate";
+       static const gchar *thisfn = "fma_icontext_is_candidate";
        gboolean is_candidate;
 
-       g_return_val_if_fail( NA_IS_ICONTEXT( context ), FALSE );
+       g_return_val_if_fail( FMA_IS_ICONTEXT( context ), FALSE );
 
        g_debug( "%s: object=%p (%s), target=%d, selection=%p (count=%d)",
                        thisfn, ( void * ) context, G_OBJECT_TYPE_NAME( context ), target, (void * ) 
selection, g_list_length( selection ));
 
-       is_candidate = v_is_candidate( NA_ICONTEXT( context ), target, selection );
+       is_candidate = v_is_candidate( FMA_ICONTEXT( context ), target, selection );
 
        if( is_candidate ){
                is_candidate =
@@ -250,13 +250,13 @@ na_icontext_is_candidate( const NAIContext *context, guint target, GList *select
 }
 
 /**
- * na_icontext_is_valid:
- * @context: the #NAIContext to be checked.
+ * fma_icontext_is_valid:
+ * @context: the #FMAIContext to be checked.
  *
  * Returns: %TRUE if this @context is valid, %FALSE else.
  *
  * This function is part of <methodname>NAIDuplicable::check_status</methodname>
- * and is called by #NAIDuplicable objects which also implement #NAIContext
+ * and is called by #NAIDuplicable objects which also implement #FMAIContext
  * interface. It so doesn't make sense of asking the object for its
  * validity status as it has already been checked before calling the
  * function.
@@ -264,12 +264,12 @@ na_icontext_is_candidate( const NAIContext *context, guint target, GList *select
  * Since: 2.30
  */
 gboolean
-na_icontext_is_valid( const NAIContext *context )
+fma_icontext_is_valid( const FMAIContext *context )
 {
-       static const gchar *thisfn = "na_icontext_is_valid";
+       static const gchar *thisfn = "fma_icontext_is_valid";
        gboolean is_valid;
 
-       g_return_val_if_fail( NA_IS_ICONTEXT( context ), FALSE );
+       g_return_val_if_fail( FMA_IS_ICONTEXT( context ), FALSE );
 
        g_debug( "%s: context=%p (%s)", thisfn, ( void * ) context, G_OBJECT_TYPE_NAME( context ));
 
@@ -283,8 +283,8 @@ na_icontext_is_valid( const NAIContext *context )
 }
 
 /**
- * na_icontext_check_mimetypes:
- * @context: the #NAIContext object to be checked.
+ * fma_icontext_check_mimetypes:
+ * @context: the #FMAIContext object to be checked.
  *
  * Check the current list of mimetypes to see if it covers all mimetypes,
  * or all regular files, or something else.
@@ -292,13 +292,13 @@ na_icontext_is_valid( const NAIContext *context )
  * Since: 2.30
  */
 void
-na_icontext_check_mimetypes( const NAIContext *context )
+fma_icontext_check_mimetypes( const FMAIContext *context )
 {
-       static const gchar *thisfn = "na_icontext_check_mimetypes";
+       static const gchar *thisfn = "fma_icontext_check_mimetypes";
        gboolean is_all;
        GSList *mimetypes, *im;
 
-       g_return_if_fail( NA_IS_ICONTEXT( context ));
+       g_return_if_fail( FMA_IS_ICONTEXT( context ));
 
        is_all = TRUE;
        mimetypes = na_object_get_mimetypes( context );
@@ -322,25 +322,25 @@ na_icontext_check_mimetypes( const NAIContext *context )
 }
 
 /**
- * na_icontext_copy:
- * @context: the target #NAIContext context.
- * @source: the source #NAIContext context.
+ * fma_icontext_copy:
+ * @context: the target #FMAIContext context.
+ * @source: the source #FMAIContext context.
  *
  * Copy specific data from @source to @context.
  *
  * Since: 3.1
  */
 void
-na_icontext_copy( NAIContext *context, const NAIContext *source )
+fma_icontext_copy( FMAIContext *context, const FMAIContext *source )
 {
        /* nothing to do for now */
 }
 
 /**
- * na_icontext_read_done:
- * @context: the #NAIContext to be prepared.
+ * fma_icontext_read_done:
+ * @context: the #FMAIContext to be prepared.
  *
- * Prepares the specified #NAIContext just after it has been read.
+ * Prepares the specified #FMAIContext just after it has been read.
  *
  * <itemizedlist>
  *   <listitem>
@@ -354,14 +354,14 @@ na_icontext_copy( NAIContext *context, const NAIContext *source )
  * Since: 2.30
  */
 void
-na_icontext_read_done( NAIContext *context )
+fma_icontext_read_done( FMAIContext *context )
 {
        na_object_check_mimetypes( context );
 }
 
 /**
- * na_icontext_set_scheme:
- * @context: the #NAIContext to be updated.
+ * fma_icontext_set_scheme:
+ * @context: the #FMAIContext to be updated.
  * @scheme: name of the scheme.
  * @selected: whether this scheme is candidate to this @context.
  *
@@ -370,11 +370,11 @@ na_icontext_read_done( NAIContext *context )
  * Since: 2.30
  */
 void
-na_icontext_set_scheme( NAIContext *context, const gchar *scheme, gboolean selected )
+fma_icontext_set_scheme( FMAIContext *context, const gchar *scheme, gboolean selected )
 {
        GSList *schemes;
 
-       g_return_if_fail( NA_IS_ICONTEXT( context ));
+       g_return_if_fail( FMA_IS_ICONTEXT( context ));
 
        schemes = na_object_get_schemes( context );
        schemes = fma_core_utils_slist_setup_element( schemes, scheme, selected );
@@ -383,8 +383,8 @@ na_icontext_set_scheme( NAIContext *context, const gchar *scheme, gboolean selec
 }
 
 /**
- * na_icontext_set_only_desktop:
- * @context: the #NAIContext to be updated.
+ * fma_icontext_set_only_desktop:
+ * @context: the #FMAIContext to be updated.
  * @desktop: name of the desktop environment.
  * @selected: whether this @desktop is candidate to this @context.
  *
@@ -393,11 +393,11 @@ na_icontext_set_scheme( NAIContext *context, const gchar *scheme, gboolean selec
  * Since: 2.30
  */
 void
-na_icontext_set_only_desktop( NAIContext *context, const gchar *desktop, gboolean selected )
+fma_icontext_set_only_desktop( FMAIContext *context, const gchar *desktop, gboolean selected )
 {
        GSList *desktops;
 
-       g_return_if_fail( NA_IS_ICONTEXT( context ));
+       g_return_if_fail( FMA_IS_ICONTEXT( context ));
 
        desktops = na_object_get_only_show_in( context );
        desktops = fma_core_utils_slist_setup_element( desktops, desktop, selected );
@@ -406,8 +406,8 @@ na_icontext_set_only_desktop( NAIContext *context, const gchar *desktop, gboolea
 }
 
 /**
- * na_icontext_set_only_desktop:
- * @context: the #NAIContext to be updated.
+ * fma_icontext_set_only_desktop:
+ * @context: the #FMAIContext to be updated.
  * @desktop: name of the desktop environment.
  * @selected: whether this @desktop is candidate to this @context.
  *
@@ -416,11 +416,11 @@ na_icontext_set_only_desktop( NAIContext *context, const gchar *desktop, gboolea
  * Since: 2.30
  */
 void
-na_icontext_set_not_desktop( NAIContext *context, const gchar *desktop, gboolean selected )
+fma_icontext_set_not_desktop( FMAIContext *context, const gchar *desktop, gboolean selected )
 {
        GSList *desktops;
 
-       g_return_if_fail( NA_IS_ICONTEXT( context ));
+       g_return_if_fail( FMA_IS_ICONTEXT( context ));
 
        desktops = na_object_get_not_show_in( context );
        desktops = fma_core_utils_slist_setup_element( desktops, desktop, selected );
@@ -429,8 +429,8 @@ na_icontext_set_not_desktop( NAIContext *context, const gchar *desktop, gboolean
 }
 
 /**
- * na_icontext_replace_folder:
- * @context: the #NAIContext to be updated.
+ * fma_icontext_replace_folder:
+ * @context: the #FMAIContext to be updated.
  * @old: the old uri.
  * @new: the new uri.
  *
@@ -439,11 +439,11 @@ na_icontext_set_not_desktop( NAIContext *context, const gchar *desktop, gboolean
  * Since: 2.30
  */
 void
-na_icontext_replace_folder( NAIContext *context, const gchar *old, const gchar *new )
+fma_icontext_replace_folder( FMAIContext *context, const gchar *old, const gchar *new )
 {
        GSList *folders;
 
-       g_return_if_fail( NA_IS_ICONTEXT( context ));
+       g_return_if_fail( FMA_IS_ICONTEXT( context ));
 
        folders = na_object_get_folders( context );
        folders = fma_core_utils_slist_remove_utf8( folders, old );
@@ -453,28 +453,28 @@ na_icontext_replace_folder( NAIContext *context, const gchar *old, const gchar *
 }
 
 static gboolean
-v_is_candidate( NAIContext *context, guint target, GList *selection )
+v_is_candidate( FMAIContext *context, guint target, GList *selection )
 {
        gboolean is_candidate;
 
        is_candidate = TRUE;
 
-       if( NA_ICONTEXT_GET_INTERFACE( context )->is_candidate ){
-               is_candidate = NA_ICONTEXT_GET_INTERFACE( context )->is_candidate( context, target, selection 
);
+       if( FMA_ICONTEXT_GET_INTERFACE( context )->is_candidate ){
+               is_candidate = FMA_ICONTEXT_GET_INTERFACE( context )->is_candidate( context, target, 
selection );
        }
 
        return( is_candidate );
 }
 
 /*
- * whether the given NAIContext object is candidate for this target
+ * whether the given FMAIContext object is candidate for this target
  * target is context menu for location, context menu for selection or toolbar for location
  * only actions are concerned by this check
  */
 static gboolean
-is_candidate_for_target( const NAIContext *object, guint target, GList *files )
+is_candidate_for_target( const FMAIContext *object, guint target, GList *files )
 {
-       static const gchar *thisfn = "na_icontext_is_candidate_for_target";
+       static const gchar *thisfn = "fma_icontext_is_candidate_for_target";
        gboolean ok = TRUE;
 
        if( NA_IS_OBJECT_ACTION( object )){
@@ -514,9 +514,9 @@ is_candidate_for_target( const NAIContext *object, guint target, GList *files )
  * only one of these two data may be set
  */
 static gboolean
-is_candidate_for_show_in( const NAIContext *object, guint target, GList *files )
+is_candidate_for_show_in( const FMAIContext *object, guint target, GList *files )
 {
-       static const gchar *thisfn = "na_icontext_is_candidate_for_show_in";
+       static const gchar *thisfn = "fma_icontext_is_candidate_for_show_in";
        gboolean ok = TRUE;
        GSList *only_in = na_object_get_only_show_in( object );
        GSList *not_in = na_object_get_not_show_in( object );
@@ -558,9 +558,9 @@ is_candidate_for_show_in( const NAIContext *object, guint target, GList *files )
  * if the data is set, it should be the path of an executable file
  */
 static gboolean
-is_candidate_for_try_exec( const NAIContext *object, guint target, GList *files )
+is_candidate_for_try_exec( const FMAIContext *object, guint target, GList *files )
 {
-       static const gchar *thisfn = "na_icontext_is_candidate_for_try_exec";
+       static const gchar *thisfn = "fma_icontext_is_candidate_for_try_exec";
        gboolean ok = TRUE;
        GError *error = NULL;
        gchar *tryexec = na_object_get_try_exec( object );
@@ -594,9 +594,9 @@ is_candidate_for_try_exec( const NAIContext *object, guint target, GList *files
 }
 
 static gboolean
-is_candidate_for_show_if_registered( const NAIContext *object, guint target, GList *files )
+is_candidate_for_show_if_registered( const FMAIContext *object, guint target, GList *files )
 {
-       static const gchar *thisfn = "na_icontext_is_candidate_for_show_if_registered";
+       static const gchar *thisfn = "fma_icontext_is_candidate_for_show_if_registered";
        gboolean ok = TRUE;
        gchar *name = na_object_get_show_if_registered( object );
 
@@ -633,9 +633,9 @@ is_candidate_for_show_if_registered( const NAIContext *object, guint target, GLi
 }
 
 static gboolean
-is_candidate_for_show_if_true( const NAIContext *object, guint target, GList *files )
+is_candidate_for_show_if_true( const FMAIContext *object, guint target, GList *files )
 {
-       static const gchar *thisfn = "na_icontext_is_candidate_for_show_if_true";
+       static const gchar *thisfn = "fma_icontext_is_candidate_for_show_if_true";
        gboolean ok = TRUE;
        gchar *command = na_object_get_show_if_true( object );
 
@@ -661,9 +661,9 @@ is_candidate_for_show_if_true( const NAIContext *object, guint target, GList *fi
 }
 
 static gboolean
-is_candidate_for_show_if_running( const NAIContext *object, guint target, GList *files )
+is_candidate_for_show_if_running( const FMAIContext *object, guint target, GList *files )
 {
-       static const gchar *thisfn = "na_icontext_is_candidate_for_show_if_running";
+       static const gchar *thisfn = "fma_icontext_is_candidate_for_show_if_running";
        gboolean ok = TRUE;
        gchar *searched;
        glibtop_proclist proclist;
@@ -721,9 +721,9 @@ is_candidate_for_show_if_running( const NAIContext *object, guint target, GList
  *  examined mimetype never match these
  */
 static gboolean
-is_candidate_for_mimetypes( const NAIContext *object, guint target, GList *files )
+is_candidate_for_mimetypes( const FMAIContext *object, guint target, GList *files )
 {
-       static const gchar *thisfn = "na_icontext_is_candidate_for_mimetypes";
+       static const gchar *thisfn = "fma_icontext_is_candidate_for_mimetypes";
        gboolean ok = TRUE;
        gboolean all = na_object_get_all_mimetypes( object );
 
@@ -815,7 +815,7 @@ is_file_mimetype( const gchar *mimetype )
 static gboolean
 is_mimetype_of( const gchar *mimetype, const gchar *ftype, gboolean is_regular )
 {
-       static const gchar *thisfn = "na_icontext_is_mimetype_of";
+       static const gchar *thisfn = "fma_icontext_is_mimetype_of";
        gboolean is_type_of;
        gchar *file_content_type, *def_content_type;
 
@@ -845,9 +845,9 @@ is_mimetype_of( const gchar *mimetype, const gchar *ftype, gboolean is_regular )
 }
 
 static gboolean
-is_candidate_for_basenames( const NAIContext *object, guint target, GList *files )
+is_candidate_for_basenames( const FMAIContext *object, guint target, GList *files )
 {
-       static const gchar *thisfn = "na_icontext_is_candidate_for_basenames";
+       static const gchar *thisfn = "fma_icontext_is_candidate_for_basenames";
        gboolean ok = TRUE;
        GSList *basenames = na_object_get_basenames( object );
 
@@ -914,9 +914,9 @@ is_candidate_for_basenames( const NAIContext *object, guint target, GList *files
 }
 
 static gboolean
-is_candidate_for_selection_count( const NAIContext *object, guint target, GList *files )
+is_candidate_for_selection_count( const FMAIContext *object, guint target, GList *files )
 {
-       static const gchar *thisfn = "na_icontext_is_candidate_for_selection_count";
+       static const gchar *thisfn = "fma_icontext_is_candidate_for_selection_count";
        gboolean ok = TRUE;
        gint limit;
        guint count;
@@ -962,9 +962,9 @@ is_candidate_for_selection_count( const NAIContext *object, guint target, GList
  * against schemes conditions.
  */
 static gboolean
-is_candidate_for_schemes( const NAIContext *object, guint target, GList *files )
+is_candidate_for_schemes( const FMAIContext *object, guint target, GList *files )
 {
-       static const gchar *thisfn = "na_icontext_is_candidate_for_schemes";
+       static const gchar *thisfn = "fma_icontext_is_candidate_for_schemes";
        gboolean ok = TRUE;
        GSList *schemes = na_object_get_schemes( object );
 
@@ -1045,9 +1045,9 @@ is_compatible_scheme( const gchar *pattern, const gchar *scheme )
  * conditions
  */
 static gboolean
-is_candidate_for_folders( const NAIContext *object, guint target, GList *files )
+is_candidate_for_folders( const FMAIContext *object, guint target, GList *files )
 {
-       static const gchar *thisfn = "na_icontext_is_candidate_for_folders";
+       static const gchar *thisfn = "fma_icontext_is_candidate_for_folders";
        gboolean ok = TRUE;
        GSList *folders = na_object_get_folders( object );
 
@@ -1108,9 +1108,9 @@ is_candidate_for_folders( const NAIContext *object, guint target, GList *files )
 }
 
 static gboolean
-is_candidate_for_capabilities( const NAIContext *object, guint target, GList *files )
+is_candidate_for_capabilities( const FMAIContext *object, guint target, GList *files )
 {
-       static const gchar *thisfn = "na_icontext_is_candidate_for_capabilities";
+       static const gchar *thisfn = "fma_icontext_is_candidate_for_capabilities";
        gboolean ok = TRUE;
        GSList *capabilities = na_object_get_capabilities( object );
 
@@ -1162,7 +1162,7 @@ is_candidate_for_capabilities( const NAIContext *object, guint target, GList *fi
 }
 
 static gboolean
-is_valid_basenames( const NAIContext *object )
+is_valid_basenames( const FMAIContext *object )
 {
        gboolean valid;
        GSList *basenames;
@@ -1185,9 +1185,9 @@ is_valid_basenames( const NAIContext *object )
  *  that no mimetype is coded as '* / something'
  */
 static gboolean
-is_valid_mimetypes( const NAIContext *object )
+is_valid_mimetypes( const FMAIContext *object )
 {
-       static const gchar *thisfn = "na_icontext_is_valid_mimetypes";
+       static const gchar *thisfn = "fma_icontext_is_valid_mimetypes";
        gboolean valid;
        GSList *mimetypes, *it;
        guint count_ok, count_errs;
@@ -1235,7 +1235,7 @@ is_valid_mimetypes( const NAIContext *object )
 }
 
 static gboolean
-is_valid_schemes( const NAIContext *object )
+is_valid_schemes( const FMAIContext *object )
 {
        gboolean valid;
        GSList *schemes;
@@ -1252,7 +1252,7 @@ is_valid_schemes( const NAIContext *object )
 }
 
 static gboolean
-is_valid_folders( const NAIContext *object )
+is_valid_folders( const FMAIContext *object )
 {
        gboolean valid;
        GSList *folders;
diff --git a/src/core/na-object-action-factory.c b/src/core/na-object-action-factory.c
index 16566e7..f2b6cb2 100644
--- a/src/core/na-object-action-factory.c
+++ b/src/core/na-object-action-factory.c
@@ -44,7 +44,7 @@
 
 extern FMADataDef data_def_id [];                      /* defined in na-object-id-factory.c */
 extern FMADataDef data_def_item [];                    /* defined in na-object-item-factory.c */
-extern FMADataDef data_def_conditions [];      /* defined in na-icontext-factory.c */
+extern FMADataDef data_def_conditions [];      /* defined in fma-icontext-factory.c */
 
 static FMADataDef data_def_action [] = {
 
diff --git a/src/core/na-object-action.c b/src/core/na-object-action.c
index 626da4e..24acc06 100644
--- a/src/core/na-object-action.c
+++ b/src/core/na-object-action.c
@@ -82,8 +82,8 @@ static void         ifactory_object_read_done( NAIFactoryObject *instance, const
 static guint        ifactory_object_write_start( NAIFactoryObject *instance, const NAIFactoryProvider 
*writer, void *writer_data, GSList **messages );
 static guint        ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider 
*writer, void *writer_data, GSList **messages );
 
-static void         icontext_iface_init( NAIContextInterface *iface, void *user_data );
-static gboolean     icontext_is_candidate( NAIContext *object, guint target, GList *selection );
+static void         icontext_iface_init( FMAIContextInterface *iface, void *user_data );
+static gboolean     icontext_is_candidate( FMAIContext *object, guint target, GList *selection );
 
 static NAObjectProfile *read_done_convert_v1_to_v2( NAIFactoryObject *instance );
 static void             read_done_deals_with_toolbar_label( NAIFactoryObject *instance );
@@ -140,7 +140,7 @@ register_type( void )
 
        type = g_type_register_static( NA_TYPE_OBJECT_ITEM, "NAObjectAction", &info, 0 );
 
-       g_type_add_interface_static( type, NA_TYPE_ICONTEXT, &icontext_iface_info );
+       g_type_add_interface_static( type, FMA_TYPE_ICONTEXT, &icontext_iface_info );
 
        g_type_add_interface_static( type, NA_TYPE_IFACTORY_OBJECT, &ifactory_object_iface_info );
 
@@ -406,7 +406,7 @@ ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider
 
        /* prepare the context after the reading
         */
-       na_icontext_read_done( NA_ICONTEXT( instance ));
+       fma_icontext_read_done( FMA_ICONTEXT( instance ));
 
        /* last, set action defaults
         */
@@ -434,7 +434,7 @@ ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider
 }
 
 static void
-icontext_iface_init( NAIContextInterface *iface, void *user_data )
+icontext_iface_init( FMAIContextInterface *iface, void *user_data )
 {
        static const gchar *thisfn = "na_object_action_icontext_iface_init";
 
@@ -444,7 +444,7 @@ icontext_iface_init( NAIContextInterface *iface, void *user_data )
 }
 
 static gboolean
-icontext_is_candidate( NAIContext *object, guint target, GList *selection )
+icontext_is_candidate( FMAIContext *object, guint target, GList *selection )
 {
        return( TRUE );
 }
diff --git a/src/core/na-object-menu-factory.c b/src/core/na-object-menu-factory.c
index 94399de..8c975fd 100644
--- a/src/core/na-object-menu-factory.c
+++ b/src/core/na-object-menu-factory.c
@@ -37,7 +37,7 @@
 
 extern FMADataDef data_def_id [];                      /* defined in na-object-id-factory.c */
 extern FMADataDef data_def_item [];                    /* defined in na-object-item-factory.c */
-extern FMADataDef data_def_conditions [];      /* defined in na-icontext-factory.c */
+extern FMADataDef data_def_conditions [];      /* defined in fma-icontext-factory.c */
 
 /*
  * As of 3.2 non copyables data are:
diff --git a/src/core/na-object-menu.c b/src/core/na-object-menu.c
index 0fa599c..d609f8a 100644
--- a/src/core/na-object-menu.c
+++ b/src/core/na-object-menu.c
@@ -77,8 +77,8 @@ static void         ifactory_object_read_done( NAIFactoryObject *instance, const
 static guint        ifactory_object_write_start( NAIFactoryObject *instance, const NAIFactoryProvider 
*writer, void *writer_data, GSList **messages );
 static guint        ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider 
*writer, void *writer_data, GSList **messages );
 
-static void         icontext_iface_init( NAIContextInterface *iface, void *user_data );
-static gboolean     icontext_is_candidate( NAIContext *object, guint target, GList *selection );
+static void         icontext_iface_init( FMAIContextInterface *iface, void *user_data );
+static gboolean     icontext_is_candidate( FMAIContext *object, guint target, GList *selection );
 
 GType
 na_object_menu_get_type( void )
@@ -127,7 +127,7 @@ register_type( void )
 
        type = g_type_register_static( NA_TYPE_OBJECT_ITEM, "NAObjectMenu", &info, 0 );
 
-       g_type_add_interface_static( type, NA_TYPE_ICONTEXT, &icontext_iface_info );
+       g_type_add_interface_static( type, FMA_TYPE_ICONTEXT, &icontext_iface_info );
 
        g_type_add_interface_static( type, NA_TYPE_IFACTORY_OBJECT, &ifactory_object_iface_info );
 
@@ -300,7 +300,7 @@ ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider
 
        /* prepare the context after the reading
         */
-       na_icontext_read_done( NA_ICONTEXT( instance ));
+       fma_icontext_read_done( FMA_ICONTEXT( instance ));
 
        /* last, set menu defaults
         */
@@ -322,7 +322,7 @@ ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider
 }
 
 static void
-icontext_iface_init( NAIContextInterface *iface, void *user_data )
+icontext_iface_init( FMAIContextInterface *iface, void *user_data )
 {
        static const gchar *thisfn = "na_object_menu_icontext_iface_init";
 
@@ -332,7 +332,7 @@ icontext_iface_init( NAIContextInterface *iface, void *user_data )
 }
 
 static gboolean
-icontext_is_candidate( NAIContext *object, guint target, GList *selection )
+icontext_is_candidate( FMAIContext *object, guint target, GList *selection )
 {
        return( TRUE );
 }
diff --git a/src/core/na-object-profile-factory.c b/src/core/na-object-profile-factory.c
index 8d80348..c1b38e1 100644
--- a/src/core/na-object-profile-factory.c
+++ b/src/core/na-object-profile-factory.c
@@ -38,7 +38,7 @@
 #include <api/fma-data-types.h>
 
 extern FMADataDef data_def_id [];                      /* defined in na-object-id-factory.c */
-extern FMADataDef data_def_conditions [];      /* defined in na-icontext-factory.c */
+extern FMADataDef data_def_conditions [];      /* defined in fma-icontext-factory.c */
 
 static FMADataDef data_def_profile [] = {
 
diff --git a/src/core/na-object-profile.c b/src/core/na-object-profile.c
index 7b7d1cb..4f62577 100644
--- a/src/core/na-object-profile.c
+++ b/src/core/na-object-profile.c
@@ -85,8 +85,8 @@ static FMADataGroup *ifactory_object_get_groups( const NAIFactoryObject *instanc
 static void         ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider *reader, 
void *reader_data, GSList **messages );
 static guint        ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider 
*writer, void *writer_data, GSList **messages );
 
-static void         icontext_iface_init( NAIContextInterface *iface, void *user_data );
-static gboolean     icontext_is_candidate( NAIContext *object, guint target, GList *selection );
+static void         icontext_iface_init( FMAIContextInterface *iface, void *user_data );
+static gboolean     icontext_is_candidate( FMAIContext *object, guint target, GList *selection );
 
 static gboolean     convert_pre_v3_parameters( NAObjectProfile *profile );
 static gboolean     convert_pre_v3_parameters_str( gchar *str );
@@ -144,7 +144,7 @@ register_type( void )
 
        type = g_type_register_static( NA_TYPE_OBJECT_ID, "NAObjectProfile", &info, 0 );
 
-       g_type_add_interface_static( type, NA_TYPE_ICONTEXT, &icontext_iface_info );
+       g_type_add_interface_static( type, FMA_TYPE_ICONTEXT, &icontext_iface_info );
 
        g_type_add_interface_static( type, NA_TYPE_IFACTORY_OBJECT, &ifactory_object_iface_info );
 
@@ -372,7 +372,7 @@ ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider
 }
 
 static void
-icontext_iface_init( NAIContextInterface *iface, void *user_data )
+icontext_iface_init( FMAIContextInterface *iface, void *user_data )
 {
        static const gchar *thisfn = "na_object_profile_icontext_iface_init";
 
@@ -382,7 +382,7 @@ icontext_iface_init( NAIContextInterface *iface, void *user_data )
 }
 
 static gboolean
-icontext_is_candidate( NAIContext *object, guint target, GList *selection )
+icontext_is_candidate( FMAIContext *object, guint target, GList *selection )
 {
        return( TRUE );
 }
@@ -643,7 +643,7 @@ read_done_ending( NAObjectProfile *profile )
 
        /* prepare the context after the reading
         */
-       na_icontext_read_done( NA_ICONTEXT( profile ));
+       fma_icontext_read_done( FMA_ICONTEXT( profile ));
 
        /* last, set profile defaults
         */
diff --git a/src/core/na-object.c b/src/core/na-object.c
index 4dc8392..2471d00 100644
--- a/src/core/na-object.c
+++ b/src/core/na-object.c
@@ -247,8 +247,8 @@ iduplicable_copy( NAIDuplicable *target, const NAIDuplicable *source, guint mode
                        na_factory_object_copy( NA_IFACTORY_OBJECT( target ), NA_IFACTORY_OBJECT( source ));
                }
 
-               if( NA_IS_ICONTEXT( target )){
-                       na_icontext_copy( NA_ICONTEXT( target ), NA_ICONTEXT( source ));
+               if( FMA_IS_ICONTEXT( target )){
+                       fma_icontext_copy( FMA_ICONTEXT( target ), FMA_ICONTEXT( source ));
                }
 
                v_copy( dest, src, mode );
@@ -277,8 +277,8 @@ iduplicable_are_equal( const NAIDuplicable *a, const NAIDuplicable *b )
                        are_equal &= na_factory_object_are_equal( NA_IFACTORY_OBJECT( a ), 
NA_IFACTORY_OBJECT( b ));
                }
 
-               if( NA_IS_ICONTEXT( a )){
-                       are_equal &= na_icontext_are_equal( NA_ICONTEXT( a ), NA_ICONTEXT( b ));
+               if( FMA_IS_ICONTEXT( a )){
+                       are_equal &= fma_icontext_are_equal( FMA_ICONTEXT( a ), FMA_ICONTEXT( b ));
                }
 
                are_equal &= v_are_equal( NA_OBJECT( a ), NA_OBJECT( b ));
@@ -306,8 +306,8 @@ iduplicable_is_valid( const NAIDuplicable *object )
                        is_valid &= na_factory_object_is_valid( NA_IFACTORY_OBJECT( object ));
                }
 
-               if( NA_IS_ICONTEXT( object )){
-                       is_valid &= na_icontext_is_valid( NA_ICONTEXT( object ));
+               if( FMA_IS_ICONTEXT( object )){
+                       is_valid &= fma_icontext_is_valid( FMA_ICONTEXT( object ));
                }
 
                is_valid &= v_is_valid( NA_OBJECT( object ));
diff --git a/src/nact/nact-iaction-tab.c b/src/nact/nact-iaction-tab.c
index 0dca172..9974e56 100644
--- a/src/nact/nact-iaction-tab.c
+++ b/src/nact/nact-iaction-tab.c
@@ -75,7 +75,7 @@ static void         interface_base_init( NactIActionTabInterface *klass );
 static void         interface_base_finalize( NactIActionTabInterface *klass );
 static void         initialize_gtk( NactIActionTab *instance );
 static void         initialize_window( NactIActionTab *instance );
-static void         on_main_item_updated( NactIActionTab *instance, NAIContext *context, guint data, void 
*empty );
+static void         on_main_item_updated( NactIActionTab *instance, FMAIContext *context, guint data, void 
*empty );
 static void         on_tree_selection_changed( NactTreeView *tview, GList *selected_items, NactIActionTab 
*instance );
 static void         on_target_selection_toggled( GtkToggleButton *button, NactIActionTab *instance );
 static void         on_target_location_toggled( GtkToggleButton *button, NactIActionTab *instance );
@@ -313,7 +313,7 @@ nact_iaction_tab_has_label( NactIActionTab *instance )
 }
 
 static void
-on_main_item_updated( NactIActionTab *instance, NAIContext *context, guint data, void *empty )
+on_main_item_updated( NactIActionTab *instance, FMAIContext *context, guint data, void *empty )
 {
        GtkWidget *label_widget;
        gchar *label;
diff --git a/src/nact/nact-iaction-tab.h b/src/nact/nact-iaction-tab.h
index 4e9ca0e..bd31cba 100644
--- a/src/nact/nact-iaction-tab.h
+++ b/src/nact/nact-iaction-tab.h
@@ -39,7 +39,7 @@
  *
  * Entry fields are enabled, as soon as an edited item has been set as a
  * property of the main window, Fields are those of NAObjectItem (i.e.
- * not NAObjectProfile, not NAIContext, but may be NAObjectAction specific).
+ * not NAObjectProfile, not FMAIContext, but may be NAObjectAction specific).
  */
 
 #include <glib-object.h>
diff --git a/src/nact/nact-ibasenames-tab.c b/src/nact/nact-ibasenames-tab.c
index 16252c5..85db9f9 100644
--- a/src/nact/nact-ibasenames-tab.c
+++ b/src/nact/nact-ibasenames-tab.c
@@ -237,7 +237,7 @@ initialize_window( NactIBasenamesTab *instance )
 static void
 on_tree_selection_changed( NactTreeView *tview, GList *selected_items, NactIBasenamesTab *instance )
 {
-       NAIContext *context;
+       FMAIContext *context;
        gboolean editable;
        gboolean enable_tab;
        GtkToggleButton *matchcase_button;
@@ -265,7 +265,7 @@ on_tree_selection_changed( NactTreeView *tview, GList *selected_items, NactIBase
 static void
 on_matchcase_toggled( GtkToggleButton *button, NactIBasenamesTab *instance )
 {
-       NAIContext *context;
+       FMAIContext *context;
        gboolean editable;
        gboolean matchcase;
        IBasenamesData *data;
diff --git a/src/nact/nact-icapabilities-tab.c b/src/nact/nact-icapabilities-tab.c
index 732de6a..ef90359 100644
--- a/src/nact/nact-icapabilities-tab.c
+++ b/src/nact/nact-icapabilities-tab.c
@@ -61,8 +61,8 @@ static void    initialize_gtk( NactICapabilitiesTab *instance );
 static void    initialize_window( NactICapabilitiesTab *instance );
 static void    on_tree_selection_changed( NactTreeView *tview, GList *selected_items, NactICapabilitiesTab 
*instance );
 static void    on_add_clicked( GtkButton *button, NactICapabilitiesTab *instance );
-static GSList *get_capabilities( NAIContext *context );
-static void    set_capabilities( NAIContext *context, GSList *list );
+static GSList *get_capabilities( FMAIContext *context );
+static void    set_capabilities( FMAIContext *context, GSList *list );
 static void    on_instance_finalized( gpointer user_data, NactICapabilitiesTab *instance );
 
 GType
@@ -206,7 +206,7 @@ initialize_window( NactICapabilitiesTab *instance )
 static void
 on_tree_selection_changed( NactTreeView *tview, GList *selected_items, NactICapabilitiesTab *instance )
 {
-       NAIContext *context;
+       FMAIContext *context;
        gboolean editable;
        gboolean enable_tab;
 
@@ -221,7 +221,7 @@ on_tree_selection_changed( NactTreeView *tview, GList *selected_items, NactICapa
 static void
 on_add_clicked( GtkButton *button, NactICapabilitiesTab *instance )
 {
-       NAIContext *context;
+       FMAIContext *context;
        GSList *capabilities;
        gchar *new_cap;
 
@@ -241,13 +241,13 @@ on_add_clicked( GtkButton *button, NactICapabilitiesTab *instance )
 }
 
 static GSList *
-get_capabilities( NAIContext *context )
+get_capabilities( FMAIContext *context )
 {
        return( na_object_get_capabilities( context ));
 }
 
 static void
-set_capabilities( NAIContext *context, GSList *list )
+set_capabilities( FMAIContext *context, GSList *list )
 {
        na_object_set_capabilities( context, list );
 }
diff --git a/src/nact/nact-icommand-tab.c b/src/nact/nact-icommand-tab.c
index 7f5a6f6..3f959a3 100644
--- a/src/nact/nact-icommand-tab.c
+++ b/src/nact/nact-icommand-tab.c
@@ -77,7 +77,7 @@ static void          interface_base_init( NactICommandTabInterface *klass );
 static void          interface_base_finalize( NactICommandTabInterface *klass );
 static void          initialize_gtk( NactICommandTab *instance );
 static void          initialize_window( NactICommandTab *instance );
-static void          on_main_item_updated( NactICommandTab *instance, NAIContext *context, guint data, void 
*empty );
+static void          on_main_item_updated( NactICommandTab *instance, FMAIContext *context, guint data, void 
*empty );
 static void          on_tree_selection_changed( NactTreeView *tview, GList *selected_items, NactICommandTab 
*instance );
 static GtkWidget    *get_label_entry( NactICommandTab *instance );
 static GtkButton    *get_legend_button( NactICommandTab *instance );
@@ -289,7 +289,7 @@ initialize_window( NactICommandTab *instance )
 }
 
 static void
-on_main_item_updated( NactICommandTab *instance, NAIContext *context, guint data, void *empty )
+on_main_item_updated( NactICommandTab *instance, FMAIContext *context, guint data, void *empty )
 {
        GtkWidget *label_widget;
        gchar *label;
diff --git a/src/nact/nact-ienvironment-tab.c b/src/nact/nact-ienvironment-tab.c
index fbe76c5..27fe0b6 100644
--- a/src/nact/nact-ienvironment-tab.c
+++ b/src/nact/nact-ienvironment-tab.c
@@ -349,7 +349,7 @@ static void
 on_tree_selection_changed( NactTreeView *tview, GList *selected_items, NactIEnvironmentTab *instance )
 {
        static const gchar *thisfn = "nact_ienvironment_tab_on_tree_selection_changed";
-       NAIContext *context;
+       FMAIContext *context;
        gboolean editable;
        gboolean enable_tab;
        gchar *sel_count, *selcount_ope, *selcount_int;
@@ -494,7 +494,7 @@ on_selcount_int_changed( GtkEntry *entry, NactIEnvironmentTab *instance )
 static void
 on_selection_count_changed( NactIEnvironmentTab *instance )
 {
-       NAIContext *context;
+       FMAIContext *context;
        gchar *selcount;
        IEnvironData *data;
 
@@ -529,7 +529,7 @@ static void
 on_show_always_toggled( GtkToggleButton *toggle_button, NactIEnvironmentTab *instance )
 {
        static const gchar *thisfn = "nact_ienvironment_tab_on_show_always_toggled";
-       NAIContext *context;
+       FMAIContext *context;
        gboolean editable;
        gboolean active;
        GtkTreeView *listview;
@@ -570,7 +570,7 @@ static void
 on_only_show_toggled( GtkToggleButton *toggle_button, NactIEnvironmentTab *instance )
 {
        static const gchar *thisfn = "nact_ienvironment_tab_on_only_show_toggled";
-       NAIContext *context;
+       FMAIContext *context;
        gboolean editable;
        gboolean active;
        GSList *show;
@@ -611,7 +611,7 @@ static void
 on_do_not_show_toggled( GtkToggleButton *toggle_button, NactIEnvironmentTab *instance )
 {
        static const gchar *thisfn = "nact_ienvironment_tab_on_do_not_show_toggled";
-       NAIContext *context;
+       FMAIContext *context;
        gboolean editable;
        gboolean active;
        GSList *show;
@@ -652,7 +652,7 @@ static void
 on_desktop_toggled( GtkCellRendererToggle *renderer, gchar *path, NactIEnvironmentTab *instance )
 {
        static const gchar *thisfn = "nact_ienvironment_tab_on_desktop_toggled";
-       NAIContext *context;
+       FMAIContext *context;
        gboolean editable;
        GtkTreeView *listview;
        GtkTreeModel *model;
@@ -706,7 +706,7 @@ on_desktop_toggled( GtkCellRendererToggle *renderer, gchar *path, NactIEnvironme
 static void
 on_try_exec_changed( GtkEntry *entry, NactIEnvironmentTab *instance )
 {
-       NAIContext *context;
+       FMAIContext *context;
        const gchar *text;
 
        g_object_get( G_OBJECT( instance ), MAIN_PROP_CONTEXT, &context, NULL );
@@ -734,7 +734,7 @@ on_try_exec_browse( GtkButton *button, NactIEnvironmentTab *instance )
 static void
 on_show_if_registered_changed( GtkEntry *entry, NactIEnvironmentTab *instance )
 {
-       NAIContext *context;
+       FMAIContext *context;
        const gchar *text;
 
        g_object_get( G_OBJECT( instance ), MAIN_PROP_CONTEXT, &context, NULL );
@@ -749,7 +749,7 @@ on_show_if_registered_changed( GtkEntry *entry, NactIEnvironmentTab *instance )
 static void
 on_show_if_true_changed( GtkEntry *entry, NactIEnvironmentTab *instance )
 {
-       NAIContext *context;
+       FMAIContext *context;
        const gchar *text;
 
        g_object_get( G_OBJECT( instance ), MAIN_PROP_CONTEXT, &context, NULL );
@@ -764,7 +764,7 @@ on_show_if_true_changed( GtkEntry *entry, NactIEnvironmentTab *instance )
 static void
 on_show_if_running_changed( GtkEntry *entry, NactIEnvironmentTab *instance )
 {
-       NAIContext *context;
+       FMAIContext *context;
        const gchar *text;
 
        g_object_get( G_OBJECT( instance ), MAIN_PROP_CONTEXT, &context, NULL );
diff --git a/src/nact/nact-ifolders-tab.c b/src/nact/nact-ifolders-tab.c
index 79634b1..fd9bbe0 100644
--- a/src/nact/nact-ifolders-tab.c
+++ b/src/nact/nact-ifolders-tab.c
@@ -214,7 +214,7 @@ initialize_window( NactIFoldersTab *instance )
 static void
 on_tree_selection_changed( NactTreeView *tview, GList *selected_items, NactIFoldersTab *instance )
 {
-       NAIContext *context;
+       FMAIContext *context;
        gboolean editable;
        gboolean enable_tab;
        GtkWidget *button;
diff --git a/src/nact/nact-imimetypes-tab.c b/src/nact/nact-imimetypes-tab.c
index 0f0e974..86225df 100644
--- a/src/nact/nact-imimetypes-tab.c
+++ b/src/nact/nact-imimetypes-tab.c
@@ -218,7 +218,7 @@ initialize_window( NactIMimetypesTab *instance )
 static void
 on_tree_selection_changed( NactTreeView *tview, GList *selected_items, NactIMimetypesTab *instance )
 {
-       NAIContext *context;
+       FMAIContext *context;
        gboolean editable;
        gboolean enable_tab;
 
diff --git a/src/nact/nact-iproperties-tab.c b/src/nact/nact-iproperties-tab.c
index dda984f..0d909a0 100644
--- a/src/nact/nact-iproperties-tab.c
+++ b/src/nact/nact-iproperties-tab.c
@@ -70,7 +70,7 @@ static void             interface_base_init( NactIPropertiesTabInterface *klass
 static void             interface_base_finalize( NactIPropertiesTabInterface *klass );
 static void             initialize_window( NactIPropertiesTab *instance );
 static void             on_tree_selection_changed( NactTreeView *tview, GList *selected_items, 
NactIPropertiesTab *instance );
-static void             on_main_item_updated( NactIPropertiesTab *instance, NAIContext *context, guint data, 
void *empty );
+static void             on_main_item_updated( NactIPropertiesTab *instance, FMAIContext *context, guint 
data, void *empty );
 static GtkButton       *get_enabled_button( NactIPropertiesTab *instance );
 static void             on_enabled_toggled( GtkToggleButton *button, NactIPropertiesTab *instance );
 static void             on_readonly_toggled( GtkToggleButton *button, NactIPropertiesTab *instance );
@@ -313,7 +313,7 @@ on_tree_selection_changed( NactTreeView *tview, GList *selected_items, NactIProp
 }
 
 static void
-on_main_item_updated( NactIPropertiesTab *instance, NAIContext *context, guint data, void *empty )
+on_main_item_updated( NactIPropertiesTab *instance, FMAIContext *context, guint data, void *empty )
 {
        static const gchar *thisfn = "nact_iproperties_tab_on_main_item_updated";
 
diff --git a/src/nact/nact-ischemes-tab.c b/src/nact/nact-ischemes-tab.c
index 71328ae..f39cf41 100644
--- a/src/nact/nact-ischemes-tab.c
+++ b/src/nact/nact-ischemes-tab.c
@@ -213,7 +213,7 @@ initialize_window( NactISchemesTab *instance )
 static void
 on_tree_selection_changed( NactTreeView *tview, GList *selected_items, NactISchemesTab *instance )
 {
-       NAIContext *context;
+       FMAIContext *context;
        gboolean editable;
        gboolean enable_tab;
        GtkWidget *button;
@@ -234,7 +234,7 @@ on_add_from_defaults( GtkButton *button, NactISchemesTab *instance )
 {
        GSList *schemes;
        gchar *new_scheme;
-       NAIContext *context;
+       FMAIContext *context;
 
        g_object_get( G_OBJECT( instance ), MAIN_PROP_CONTEXT, &context, NULL );
        g_return_if_fail( context );
diff --git a/src/nact/nact-main-tab.h b/src/nact/nact-main-tab.h
index 3eb70ef..864f941 100644
--- a/src/nact/nact-main-tab.h
+++ b/src/nact/nact-main-tab.h
@@ -30,7 +30,7 @@
 #ifndef __NACT_MAIN_TAB_H__
 #define __NACT_MAIN_TAB_H__
 
-#include <api/na-icontext.h>
+#include <api/fma-icontext.h>
 
 #include "nact-main-window-def.h"
 
diff --git a/src/nact/nact-match-list.c b/src/nact/nact-match-list.c
index 3cf24e4..a51cc17 100644
--- a/src/nact/nact-match-list.c
+++ b/src/nact/nact-match-list.c
@@ -327,7 +327,7 @@ static void
 on_tree_selection_changed( NactTreeView *treeview, GList *selected_items, MatchListData *data )
 {
        static const gchar *thisfn = "nact_match_list_on_tree_selection_changed";
-       NAIContext *context;
+       FMAIContext *context;
        gboolean enable_tab;
        GSList *filters;
        GtkTreeModel *model;
@@ -447,7 +447,7 @@ on_filter_edited( GtkCellRendererText *renderer, const gchar *path_str, const gc
        GtkTreeIter iter;
        GtkTreePath *path;
        gchar *old_text;
-       NAIContext *context;
+       FMAIContext *context;
        gboolean must_match, must_not_match;
        gchar *to_add, *to_remove;
        GSList *filters;
@@ -456,7 +456,7 @@ on_filter_edited( GtkCellRendererText *renderer, const gchar *path_str, const gc
        g_return_if_fail( data->editable_filter );
 
        g_object_get( G_OBJECT( data->window ), MAIN_PROP_CONTEXT, &context, NULL );
-       g_return_if_fail( NA_IS_ICONTEXT( context ));
+       g_return_if_fail( FMA_IS_ICONTEXT( context ));
 
        model = gtk_tree_view_get_model( data->listview );
        path = gtk_tree_path_new_from_string( path_str );
@@ -566,7 +566,7 @@ on_must_match_toggled( GtkCellRendererToggle *cell_renderer, gchar *path_str, Ma
 {
        /*static const gchar *thisfn = "nact_match_list_on_must_match_toggled";*/
        gchar *filter;
-       NAIContext *context;
+       FMAIContext *context;
        GSList *filters;
        gchar *to_remove;
        gboolean active;
@@ -579,7 +579,7 @@ on_must_match_toggled( GtkCellRendererToggle *cell_renderer, gchar *path_str, Ma
        if( data->editable_item ){
                if( !active ){
                        g_object_get( G_OBJECT( data->window ), MAIN_PROP_CONTEXT, &context, NULL );
-                       g_return_if_fail( NA_IS_ICONTEXT( context ));
+                       g_return_if_fail( FMA_IS_ICONTEXT( context ));
 
                        set_match_status( path_str, TRUE, FALSE, data );
 
@@ -618,7 +618,7 @@ on_must_not_match_toggled( GtkCellRendererToggle *cell_renderer, gchar *path_str
 {
        /*static const gchar *thisfn = "nact_match_list_on_must_not_match_toggled";*/
        gchar *filter;
-       NAIContext *context;
+       FMAIContext *context;
        GSList *filters;
        gchar *to_add;
        gboolean active;
@@ -631,7 +631,7 @@ on_must_not_match_toggled( GtkCellRendererToggle *cell_renderer, gchar *path_str
        if( data->editable_item ){
                if( !active ){
                        g_object_get( G_OBJECT( data->window ), MAIN_PROP_CONTEXT, &context, NULL );
-                       g_return_if_fail( NA_IS_ICONTEXT( context ));
+                       g_return_if_fail( FMA_IS_ICONTEXT( context ));
 
                        set_match_status( path_str, FALSE, TRUE, data );
 
@@ -674,7 +674,7 @@ on_selection_changed( GtkTreeSelection *selection, MatchListData *data )
 static void
 add_filter( MatchListData *data, const gchar *filter, const gchar *prefix )
 {
-       NAIContext *context;
+       FMAIContext *context;
        GSList *filters;
        gchar *to_add;
 
@@ -716,7 +716,7 @@ delete_current_row( MatchListData *data )
        GtkTreePath *path;
        GtkTreeIter iter;
        gchar *filter;
-       NAIContext *context;
+       FMAIContext *context;
        GSList *filters;
        gchar *to_remove;
 
diff --git a/src/nact/nact-schemes-list.c b/src/nact/nact-schemes-list.c
index 1dcb5af..ea3fb81 100644
--- a/src/nact/nact-schemes-list.c
+++ b/src/nact/nact-schemes-list.c
@@ -191,7 +191,7 @@ nact_schemes_list_create_model( GtkTreeView *treeview, guint mode )
  * When mode is for preferences, this is all that is required for runtime
  * initialization.
  *
- * When mode is for add from defaults, i.e. when editing #NAIContext schemes
+ * When mode is for add from defaults, i.e. when editing #FMAIContext schemes
  * conditions, then #nact_schemes_list_setup_values() must also be called in
  * order to actually setup the already used schemes.
  */
@@ -374,7 +374,7 @@ init_view_select_first_row( SchemesListData *data )
  * @window: the #BaseWindow which embeds this treeview.
  * @schemes: a #GSList of already used schemes.
  *
- * Set the used schemes for the current #NAIContext.
+ * Set the used schemes for the current #FMAIContext.
  */
 void
 nact_schemes_list_setup_values( BaseWindow *window, GSList *schemes )
diff --git a/src/nact/nact-schemes-list.h b/src/nact/nact-schemes-list.h
index 1cb14f8..f4a8756 100644
--- a/src/nact/nact-schemes-list.h
+++ b/src/nact/nact-schemes-list.h
@@ -49,7 +49,7 @@
  *   adding/removing a scheme is possible
  *
  * Starting with 2.31.x serie (future 3.0), the scheme conditions of a
- * #NAIContext are handled by nact-match-list.{c,h} set of function.
+ * #FMAIContext are handled by nact-match-list.{c,h} set of function.
  * This set of functions is only used:
  *  a) to edit the preferences
  *     add/remove scheme
@@ -57,7 +57,7 @@
  *     In this mode, the widget is embedded in the Preferences notebook.
  *     Modifications are saved when user clicks the global OK button.
  *  b) to select a scheme from the default list
- *     schemes already used by the current #NAIContext are marked as used
+ *     schemes already used by the current #FMAIContext are marked as used
  *     edition of the current list is not available
  *     In this mode, widget is embedded in a dedicated #NactAddSchemeDialog
  *     dialog box
diff --git a/src/nact/nact-tree-model.c b/src/nact/nact-tree-model.c
index 9115d11..0a2368c 100644
--- a/src/nact/nact-tree-model.c
+++ b/src/nact/nact-tree-model.c
@@ -106,7 +106,7 @@ static void     instance_dispose( GObject *model );
 static void     instance_finalize( GObject *model );
 static void     connect_item_updated_signal( NactTreeModel *tmodel );
 static void     on_settings_order_mode_changed( const gchar *group, const gchar *key, gconstpointer 
new_value, gboolean mandatory, NactTreeModel *model );
-static void     on_main_item_updated( BaseWindow *window, NAIContext *context, guint data, NactTreeModel 
*model );
+static void     on_main_item_updated( BaseWindow *window, FMAIContext *context, guint data, NactTreeModel 
*model );
 static void     setup_dnd_edition( NactTreeModel *tmodel );
 static void     append_item( GtkTreeStore *model, GtkTreeView *treeview, GtkTreeIter *parent, GtkTreeIter 
*iter, const NAObject *object );
 static void     display_item( GtkTreeStore *model, GtkTreeView *treeview, GtkTreeIter *iter, const NAObject 
*object );
@@ -525,7 +525,7 @@ on_settings_order_mode_changed( const gchar *group, const gchar *key, gconstpoin
  * if force_display is true, then refresh the display of the view
  */
 static void
-on_main_item_updated( BaseWindow *window, NAIContext *context, guint data, NactTreeModel *model )
+on_main_item_updated( BaseWindow *window, FMAIContext *context, guint data, NactTreeModel *model )
 {
        static const gchar *thisfn = "nact_tree_model_on_main_item_updated";
        GtkTreePath *path;
diff --git a/src/utils/nautilus-actions-run.c b/src/utils/nautilus-actions-run.c
index 88ebf1e..daa50e6 100644
--- a/src/utils/nautilus-actions-run.c
+++ b/src/utils/nautilus-actions-run.c
@@ -160,7 +160,7 @@ main( int argc, char** argv )
                exit( status );
        }
 
-       if( !na_icontext_is_candidate( NA_ICONTEXT( action ), ITEM_TARGET_ANY, targets )){
+       if( !fma_icontext_is_candidate( FMA_ICONTEXT( action ), ITEM_TARGET_ANY, targets )){
                g_printerr( _( "Action %s is not a valid candidate. Exiting.\n" ), id );
                exit( status );
        }
@@ -392,7 +392,7 @@ get_profile_for_targets( NAObjectAction *action, GList *targets )
        profiles = na_object_get_items( action );
 
        for( ip = profiles ; ip && !candidate ; ip = ip->next ){
-               if( na_icontext_is_candidate( NA_ICONTEXT( ip->data ), ITEM_TARGET_ANY, targets )){
+               if( fma_icontext_is_candidate( FMA_ICONTEXT( ip->data ), ITEM_TARGET_ANY, targets )){
                        candidate = NA_OBJECT_PROFILE( ip->data );
                }
        }


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/api/na-icontext.h b/src/api/fma-icontext.h
similarity index 58%
rename from src/api/na-icontext.h
rename to src/api/fma-icontext.h
index bb7c0b2..035cf4c 100644
--- a/src/api/na-icontext.h
+++ b/src/api/fma-icontext.h
@@ -32,9 +32,9 @@
 
 /**
  * SECTION: icontext
- * @title: NAIContext
+ * @title: FMAIContext
  * @short_description: The Contextual Interface
- * @include: file-manager-actions/na-icontext.h
+ * @include: file-manager-actions/fma-icontext.h
  *
  * This interface is implemented by all #NAObject -derived objects
  * whose the display in the Nautilus context menu is subject to some
@@ -49,16 +49,16 @@
 
 G_BEGIN_DECLS
 
-#define NA_TYPE_ICONTEXT                      ( na_icontext_get_type())
-#define NA_ICONTEXT( instance )               ( G_TYPE_CHECK_INSTANCE_CAST( instance, NA_TYPE_ICONTEXT, 
NAIContext ))
-#define NA_IS_ICONTEXT( instance )            ( G_TYPE_CHECK_INSTANCE_TYPE( instance, NA_TYPE_ICONTEXT ))
-#define NA_ICONTEXT_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), 
NA_TYPE_ICONTEXT, NAIContextInterface ))
+#define FMA_TYPE_ICONTEXT                      ( fma_icontext_get_type())
+#define FMA_ICONTEXT( instance )               ( G_TYPE_CHECK_INSTANCE_CAST( instance, FMA_TYPE_ICONTEXT, 
FMAIContext ))
+#define FMA_IS_ICONTEXT( instance )            ( G_TYPE_CHECK_INSTANCE_TYPE( instance, FMA_TYPE_ICONTEXT ))
+#define FMA_ICONTEXT_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), 
FMA_TYPE_ICONTEXT, FMAIContextInterface ))
 
-typedef struct _NAIContext                    NAIContext;
-typedef struct _NAIContextInterfacePrivate    NAIContextInterfacePrivate;
+typedef struct _FMAIContext                    FMAIContext;
+typedef struct _FMAIContextInterfacePrivate    FMAIContextInterfacePrivate;
 
 /**
- * NAIContextInterface:
+ * FMAIContextInterface:
  * @is_candidate: determines if the given NAObject-derived object is
  *                candidate to display in Nautilus.
  *
@@ -68,17 +68,17 @@ typedef struct _NAIContextInterfacePrivate    NAIContextInterfacePrivate;
 typedef struct {
        /*< private >*/
        GTypeInterface              parent;
-       NAIContextInterfacePrivate *private;
+       FMAIContextInterfacePrivate *private;
 
        /*< public >*/
        /**
         * is_candidate:
         * @object: this NAIContext object.
         * @target: the initial target which triggered this function's stack.
         *  This target is defined in na-object-item.h.
         * @selection: the current selection as a GList of NautilusFileInfo.
         *
         * The NAIContext implementor may take advantage of this
         * virtual function to check for its own specific data. Only if the
         * implementor does return %TRUE (or just doesn't implement this
         * virtual), the conditions themselves will be checked.
@@ -88,24 +88,24 @@ typedef struct {
         *
         * Since: 2.30
         */
-       gboolean ( *is_candidate )( NAIContext *object, guint target, GList *selection );
+       gboolean ( *is_candidate )( FMAIContext *object, guint target, GList *selection );
 }
-       NAIContextInterface;
+       FMAIContextInterface;
 
-GType    na_icontext_get_type( void );
+GType    fma_icontext_get_type( void );
 
-gboolean na_icontext_are_equal       ( const NAIContext *a, const NAIContext *b );
-gboolean na_icontext_is_candidate    ( const NAIContext *context, guint target, GList *selection );
-gboolean na_icontext_is_valid        ( const NAIContext *context );
+gboolean fma_icontext_are_equal       ( const FMAIContext *a, const FMAIContext *b );
+gboolean fma_icontext_is_candidate    ( const FMAIContext *context, guint target, GList *selection );
+gboolean fma_icontext_is_valid        ( const FMAIContext *context );
 
-void     na_icontext_check_mimetypes ( const NAIContext *context );
+void     fma_icontext_check_mimetypes ( const FMAIContext *context );
 
-void     na_icontext_copy            ( NAIContext *context, const NAIContext *source );
-void     na_icontext_read_done       ( NAIContext *context );
-void     na_icontext_set_scheme      ( NAIContext *context, const gchar *scheme, gboolean selected );
-void     na_icontext_set_only_desktop( NAIContext *context, const gchar *desktop, gboolean selected );
-void     na_icontext_set_not_desktop ( NAIContext *context, const gchar *desktop, gboolean selected );
-void     na_icontext_replace_folder  ( NAIContext *context, const gchar *old, const gchar *new );
+void     fma_icontext_copy            ( FMAIContext *context, const FMAIContext *source );
+void     fma_icontext_read_done       ( FMAIContext *context );
+void     fma_icontext_set_scheme      ( FMAIContext *context, const gchar *scheme, gboolean selected );
+void     fma_icontext_set_only_desktop( FMAIContext *context, const gchar *desktop, gboolean selected );
+void     fma_icontext_set_not_desktop ( FMAIContext *context, const gchar *desktop, gboolean selected );
+void     fma_icontext_replace_folder  ( FMAIContext *context, const gchar *old, const gchar *new );
 
 G_END_DECLS
 
@@ -68,17 +68,17 @@ typedef struct _NAIContextInterfacePrivate    NAIContextInterfacePrivate;
        /**
         * is_candidate:
-        * @object: this NAIContext object.
+        * @object: this FMAIContext object.
         * @target: the initial target which triggered this function's stack.
         *  This target is defined in na-object-item.h.
@@ -68,17 +68,17 @@ typedef struct _NAIContextInterfacePrivate    NAIContextInterfacePrivate;
         * @selection: the current selection as a GList of NautilusFileInfo.
         *
-        * The NAIContext implementor may take advantage of this
+        * The FMAIContext implementor may take advantage of this
         * virtual function to check for its own specific data. Only if the
         * implementor does return %TRUE (or just doesn't implement this
diff --git a/src/nact/nact-main-window.c b/src/nact/nact-main-window.c
index 8c63c8e..84ab59c 100644
--- a/src/nact/nact-main-window.c
+++ b/src/nact/nact-main-window.c
@@ -104,10 +104,10 @@ struct _NactMainWindowPrivate {
        /**
         * Current context.
         *
         * This is the #NAIContext data which corresponds to @current_profile
         * or @current_item, depending of which one is actually selected.
         */
-       NAIContext      *current_context;
+       FMAIContext      *current_context;
 
        /**
         * Some convenience objects and data.
@@ -176,7 +176,7 @@ static void       setup_monitor_pivot( NactMainWindow *main_window );
 static void       on_block_items_changed_timeout( NactMainWindow *window );
 static void       on_tree_view_modified_status_changed( NactTreeView *treeview, gboolean is_modified, 
NactMainWindow *window );
 static void       on_tree_view_selection_changed( NactTreeView *treeview, GList *selected_items, 
NactMainWindow *window );
-static void       on_tab_item_updated( NactMainWindow *window, NAIContext *context, guint data, void *empty 
);
+static void       on_tab_item_updated( NactMainWindow *window, FMAIContext *context, guint data, void *empty 
);
 static void       raz_selection_properties( NactMainWindow *window );
 static void       setup_current_selection( NactMainWindow *window, NAObjectId *selected_row );
 static void       setup_dialog_title( NactMainWindow *window );
@@ -342,8 +342,8 @@ class_init( NactMainWindowClass *klass )
        g_object_class_install_property( object_class, MAIN_PROP_CONTEXT_ID,
                        g_param_spec_pointer(
                                        MAIN_PROP_CONTEXT,
-                                       _( "Current NAIContext" ),
-                                       _( "A pointer to the currently edited NAIContext" ),
+                                       _( "Current FMAIContext" ),
+                                       _( "A pointer to the currently edited FMAIContext" ),
                                        G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE ));
 
        g_object_class_install_property( object_class, MAIN_PROP_EDITABLE_ID,
@@ -373,7 +373,7 @@ class_init( NactMainWindowClass *klass )
         *
         * Handler:
         *   void handler( NactMainWindow *main_window,
-        *                              NAIContext *updated_context,
+        *                              FMAIContext *updated_context,
         *                              guint       updated_data,
         *                              void       *user_data );
         */
@@ -1004,7 +1004,7 @@ on_tree_view_selection_changed( NactTreeView *treeview, GList *selected_items, N
 }
 
 static void
-on_tab_item_updated( NactMainWindow *window, NAIContext *context, guint data, void *empty )
+on_tab_item_updated( NactMainWindow *window, FMAIContext *context, guint data, void *empty )
 {
        static const gchar *thisfn = "nact_main_window_on_tab_item_updated";
 
@@ -1045,13 +1045,13 @@ setup_current_selection( NactMainWindow *window, NAObjectId *selected_row )
 
        if( NA_IS_OBJECT_PROFILE( selected_row )){
                window->private->current_profile = NA_OBJECT_PROFILE( selected_row );
-               window->private->current_context = NA_ICONTEXT( selected_row );
+               window->private->current_context = FMA_ICONTEXT( selected_row );
                window->private->current_item = NA_OBJECT_ITEM( na_object_get_parent( selected_row ));
 
        } else {
                g_return_if_fail( NA_IS_OBJECT_ITEM( selected_row ));
                window->private->current_item = NA_OBJECT_ITEM( selected_row );
-               window->private->current_context = NA_ICONTEXT( selected_row );
+               window->private->current_context = FMA_ICONTEXT( selected_row );
 
                if( NA_IS_OBJECT_ACTION( selected_row )){
                        nb_profiles = na_object_get_items_count( selected_row );
@@ -1059,7 +1059,7 @@ setup_current_selection( NactMainWindow *window, NAObjectId *selected_row )
                        if( nb_profiles == 1 ){
                                profiles = na_object_get_items( selected_row );
                                window->private->current_profile = NA_OBJECT_PROFILE( profiles->data );
-                               window->private->current_context = NA_ICONTEXT( profiles->data );
+                               window->private->current_context = FMA_ICONTEXT( profiles->data );
                        }
                }
        }
@@ -104,10 +104,10 @@ struct _NactMainWindowPrivate {
         * Current context.
         *
-        * This is the #NAIContext data which corresponds to @current_profile
+        * This is the #FMAIContext data which corresponds to @current_profile
         * or @current_item, depending of which one is actually selected.
         */
diff --git a/src/plugin-menu/nautilus-actions.c b/src/plugin-menu/nautilus-actions.c
index fdba6f5..1e900c1 100644
--- a/src/plugin-menu/nautilus-actions.c
+++ b/src/plugin-menu/nautilus-actions.c
@@ -87,7 +87,7 @@ static GList            *menu_provider_get_toolbar_items( NautilusMenuProvider *
 static GList            *build_nautilus_menu( NautilusActions *plugin, guint target, GList *selection );
 static GList            *build_nautilus_menu_rec( GList *tree, guint target, GList *selection, NATokens 
*tokens );
 static NAObjectItem     *expand_tokens_item( const NAObjectItem *item, NATokens *tokens );
-static void              expand_tokens_context( NAIContext *context, NATokens *tokens );
+static void              expand_tokens_context( FMAIContext *context, NATokens *tokens );
 static NAObjectProfile  *get_candidate_profile( NAObjectAction *action, guint target, GList *files );
 static NautilusMenuItem *create_item_from_profile( NAObjectProfile *profile, guint target, GList *files, 
NATokens *tokens );
 static NautilusMenuItem *create_item_from_menu( NAObjectMenu *menu, GList *subitems, guint target );
@@ -547,8 +547,8 @@ build_nautilus_menu_rec( GList *tree, guint target, GList *selection, NATokens *
                label = na_object_get_label( it->data );
                g_debug( "%s: examining %s", thisfn, label );
 
-               if( !na_icontext_is_candidate( NA_ICONTEXT( it->data ), target, selection )){
-                       g_debug( "%s: is not candidate (NAIContext): %s", thisfn, label );
+               if( !fma_icontext_is_candidate( FMA_ICONTEXT( it->data ), target, selection )){
+                       g_debug( "%s: is not candidate (FMAIContext): %s", thisfn, label );
                        g_free( label );
                        continue;
                }
@@ -664,9 +664,9 @@ expand_tokens_item( const NAObjectItem *src, NATokens *tokens )
                g_free( new );
        }
 
        /* A NAObjectItem, whether it is an action or a menu, is also a NAIContext
         */
-       expand_tokens_context( NA_ICONTEXT( item ), tokens );
+       expand_tokens_context( FMA_ICONTEXT( item ), tokens );
 
        /* subitems lists, whether this is the profiles list of an action
         * or the items list of a menu, may be dynamic and embed a command;
@@ -704,9 +704,9 @@ expand_tokens_item( const NAObjectItem *src, NATokens *tokens )
                        g_free( old );
                        g_free( new );
 
                        /* a NAObjectProfile is also a NAIContext
                         */
-                       expand_tokens_context( NA_ICONTEXT( it->data ), tokens );
+                       expand_tokens_context( FMA_ICONTEXT( it->data ), tokens );
                }
        }
 
@@ -714,7 +714,7 @@ expand_tokens_item( const NAObjectItem *src, NATokens *tokens )
 }
 
 static void
-expand_tokens_context( NAIContext *context, NATokens *tokens )
+expand_tokens_context( FMAIContext *context, NATokens *tokens )
 {
        gchar *old, *new;
 
@@ -761,7 +761,7 @@ get_candidate_profile( NAObjectAction *action, guint target, GList *files )
        for( ip = profiles ; ip && !candidate ; ip = ip->next ){
                NAObjectProfile *profile = NA_OBJECT_PROFILE( ip->data );
 
-               if( na_icontext_is_candidate( NA_ICONTEXT( profile ), target, files )){
+               if( fma_icontext_is_candidate( FMA_ICONTEXT( profile ), target, files )){
                        profile_label = na_object_get_label( profile );
                        g_debug( "%s: selecting %s (profile=%p '%s')", thisfn, action_label, ( void * ) 
@@ -664,9 +664,9 @@ expand_tokens_item( const NAObjectItem *src, NATokens *tokens )
        }
 
-       /* A NAObjectItem, whether it is an action or a menu, is also a NAIContext
+       /* A NAObjectItem, whether it is an action or a menu, is also a FMAIContext
         */
@@ -704,9 +704,9 @@ expand_tokens_item( const NAObjectItem *src, NATokens *tokens )
                        g_free( new );
 
-                       /* a NAObjectProfile is also a NAIContext
+                       /* a NAObjectProfile is also a FMAIContext
                         */
profile, profile_label );
                        g_free( profile_label );